==> TencentMapSDK_iOS_3D_v6.4.1.zip: TencentMapSDK_iOS_3D_v6.4.1/html/search/all_7.js <==
var searchData=
[
  ['gap_0',['gap',['../interface_q_vector_heat_overlay_option.html#abf2999d5728a8447f58b8d8fce6f09f0',1,'QVectorHeatOverlayOption::gap'],['../interface_q_vector_heat_overlay.html#ad311acde9066aa7ddfac8250281eeaf3',1,'QVectorHeatOverlay::gap']]],
  ['gas_5femisstand_1',['gas_emisstand',['../interface_q_m_s_truck_distance_matrix_search_option.html#a4d98be145e8e7e567f114738bcc8ad3c',1,'QMSTruckDistanceMatrixSearchOption::gas_emisstand'],['../interface_q_m_s_trucking_route_search_option.html#a77a127aafef8e07a0f2cc3e633916b27',1,'QMSTruckingRouteSearchOption::gas_emisstand']]],
  ['georeferencepoint_2',['geoReferencePoint',['../interface_q_vector_heat_overlay.html#a95f7c170a64bf2dc06dd180dc32c779d',1,'QVectorHeatOverlay']]],
  ['get_5fmp_3',['get_mp',['../interface_q_m_s_driving_route_search_option.html#a52c0ede915f7fb606b47fa2f2d36e9ff',1,'QMSDrivingRouteSearchOption::get_mp'],['../interface_q_m_s_trucking_route_search_option.html#a318f9bf7c16ac10b19b6b3edae21f6fa',1,'QMSTruckingRouteSearchOption::get_mp']]],
  ['get_5fpoi_4',['get_poi',['../interface_q_m_s_reverse_geo_code_search_option.html#ae925bb0189722a7fc4377241c58ea868',1,'QMSReverseGeoCodeSearchOption']]],
  ['get_5fpolygon_5',['get_polygon',['../interface_q_m_s_district_base_search_option.html#a4a23e12c89af40ca99ca40d970df88f6',1,'QMSDistrictBaseSearchOption']]],
  ['get_5fspeed_6',['get_speed',['../interface_q_m_s_driving_route_search_option.html#ad6996f72693b0ced7ec3cfb70262e0b4',1,'QMSDrivingRouteSearchOption::get_speed'],['../interface_q_m_s_trucking_route_search_option.html#a738485034a52b79dc8fbbd962683bc36',1,'QMSTruckingRouteSearchOption::get_speed']]],
  ['get_5fsubpois_7',['get_subpois',['../interface_q_m_s_poi_search_option.html#a49aa0b5afabb3efaaf19b2f33bd57377',1,'QMSPoiSearchOption::get_subpois'],['../interface_q_m_s_suggestion_search_option.html#a022d4bcdb432eb7cb0d77b1c7b65247e',1,'QMSSuggestionSearchOption::get_subpois']]],
  ['getaggregationunit_3a_8',['getAggregationUnit:',['../interface_q_vector_heat_overlay.html#a33a877a440d54becf8c6fab383a4ea44',1,'QVectorHeatOverlay']]],
  ['getcoordinates_3arange_3a_9',['getCoordinates:range:',['../interface_q_multi_point.html#af8f0b03a6d552ae44db866eaae969168',1,'QMultiPoint']]],
  ['getdebugerror_10',['getDebugError',['../category_q_map_view_07_debug_08.html#a21e9040c774ea10c030031bb6015ff61',1,'QMapView(Debug)::getDebugError()'],['../interface_q_map_view.html#a21e9040c774ea10c030031bb6015ff61',1,'QMapView::getDebugError()']]],
  ['getmapcacheclearsizelimitbytype_3a_11',['getMapCacheClearSizeLimitByType:',['../interface_q_map_services.html#a8521b7c5a1d3df1f27843e0872fdf4f8',1,'QMapServices']]],
  ['getoff_12',['getoff',['../interface_q_m_s_busing_route_transit_line.html#a421dcc84e6dcff45c9c0a0cc545638cd',1,'QMSBusingRouteTransitLine']]],
  ['geton_13',['geton',['../interface_q_m_s_busing_route_transit_line.html#afdc5009514ab429d0497fbd883c16a1b',1,'QMSBusingRouteTransitLine']]],
  ['gettype_14',['getType',['../interface_q_g_l_overlay.html#add45689595ca4e2b671693f65add4714',1,'QGLOverlay']]],
  ['gloverlay_3adidtap_3a_15',['glOverlay:didTap:',['../protocol_q_g_l_overlay_delegate-p.html#a35159914885fc55184a7b1f627402581',1,'QGLOverlayDelegate-p']]],
  ['gloverlay_3aloadstatus_3awithprogress_3a_16',['glOverlay:loadStatus:withProgress:',['../protocol_q_g_l_overlay_delegate-p.html#a89d557a856b7540389060e25500ae741',1,'QGLOverlayDelegate-p']]],
  ['glpointratio_17',['glPointRatio',['../interface_q_g_l_overlay.html#a3bfc3b02b8cb1671efe1a2f9a67febe5',1,'QGLOverlay::glPointRatio()'],['../interface_q_map_view.html#a1153b3001c1bf2d26ae1a7cc6deac724',1,'QMapView::glPointRatio()']]],
  ['glprojectionmatrix_18',['glProjectionMatrix',['../interface_q_g_l_overlay.html#a112a5d88c014a912afa040891a8b855f',1,'QGLOverlay::glProjectionMatrix()'],['../interface_q_map_view.html#a10f669fc7d40926b07dbf0c7094c4dc3',1,'QMapView::glProjectionMatrix()']]],
  ['glvertexforcoordinate_3a_19',['glVertexForCoordinate:',['../interface_q_g_l_overlay.html#aad3349a4257ddbb13ddbae55e63ccaa6',1,'QGLOverlay::glVertexForCoordinate:()'],['../interface_q_map_view.html#afc8017803591b5e9f311991c82c80452',1,'QMapView::glVertexForCoordinate:()']]],
  ['glviewmatrix_20',['glViewMatrix',['../interface_q_g_l_overlay.html#a9c3ba591a9b63f3d02d762e1c1d1aafd',1,'QGLOverlay::glViewMatrix()'],['../interface_q_map_view.html#ae53128be3cb0722e367cd10cad4eac3b',1,'QMapView::glViewMatrix()']]],
  ['goods_5ftype_21',['goods_type',['../interface_q_m_s_truck_distance_matrix_search_option.html#a8b1570b3928ec37c647ce84f61ac84f2',1,'QMSTruckDistanceMatrixSearchOption::goods_type'],['../interface_q_m_s_trucking_route_search_option.html#ab7e949c3b8f1b9c487b48e101491b0af',1,'QMSTruckingRouteSearchOption::goods_type']]],
  ['gradient_22',['gradient',['../interface_q_heat_overlay.html#a0f6e888b1b6661f201a8f2522601f9c8',1,'QHeatOverlay::gradient'],['../interface_q_heat_tile_overlay.html#a100bde6f740ac39c4f726d73527000d8',1,'QHeatTileOverlay::gradient']]],
  ['gravityline_23',['gravityLine',['../interface_q_user_location_presentation.html#ab85b87e9bbcdc13d6e88a84e18245882',1,'QUserLocationPresentation']]],
  ['groundoverlaywithbounds_3aicon_3a_24',['groundOverlayWithBounds:icon:',['../interface_q_ground_overlay.html#aa96e4b1bc372286ba4084eec5e584277',1,'QGroundOverlay']]],
  ['groundoverlaywithcoordinate_3azoomlevel_3aanchor_3aicon_3a_25',['groundOverlayWithCoordinate:zoomLevel:anchor:icon:',['../interface_q_ground_overlay.html#abc35c27890b4f108fa06e80a2c335b3b',1,'QGroundOverlay']]],
  ['guid_26',['guid',['../interface_q_indoor_building.html#a81c1f56da5b767ab06d6f8ef6b2f7e24',1,'QIndoorBuilding']]]
];

==> TencentMapSDK_iOS_3D_v6.8.0.zip: TencentMapSDK_iOS_3D_v6.8.0/html/search/all_7.js <==
var searchData=
[
  ['gap_0',['gap',['../interface_q_vector_heat_overlay_option.html#abf2999d5728a8447f58b8d8fce6f09f0',1,'QVectorHeatOverlayOption::gap'],['../interface_q_vector_heat_overlay.html#ad311acde9066aa7ddfac8250281eeaf3',1,'QVectorHeatOverlay::gap']]],
  ['gas_5femisstand_1',['gas_emisstand',['../interface_q_m_s_truck_distance_matrix_search_option.html#a4d98be145e8e7e567f114738bcc8ad3c',1,'QMSTruckDistanceMatrixSearchOption::gas_emisstand'],['../interface_q_m_s_trucking_route_search_option.html#a77a127aafef8e07a0f2cc3e633916b27',1,'QMSTruckingRouteSearchOption::gas_emisstand']]],
  ['georeferencepoint_2',['geoReferencePoint',['../interface_q_vector_heat_overlay.html#a95f7c170a64bf2dc06dd180dc32c779d',1,'QVectorHeatOverlay']]],
  ['get_5fmp_3',['get_mp',['../interface_q_m_s_driving_route_search_option.html#a52c0ede915f7fb606b47fa2f2d36e9ff',1,'QMSDrivingRouteSearchOption::get_mp'],['../interface_q_m_s_trucking_route_search_option.html#a318f9bf7c16ac10b19b6b3edae21f6fa',1,'QMSTruckingRouteSearchOption::get_mp']]],
  ['get_5fpoi_4',['get_poi',['../interface_q_m_s_reverse_geo_code_search_option.html#ae925bb0189722a7fc4377241c58ea868',1,'QMSReverseGeoCodeSearchOption']]],
  ['get_5fpolygon_5',['get_polygon',['../interface_q_m_s_district_base_search_option.html#a4a23e12c89af40ca99ca40d970df88f6',1,'QMSDistrictBaseSearchOption']]],
  ['get_5fspeed_6',['get_speed',['../interface_q_m_s_driving_route_search_option.html#ad6996f72693b0ced7ec3cfb70262e0b4',1,'QMSDrivingRouteSearchOption::get_speed'],['../interface_q_m_s_trucking_route_search_option.html#a738485034a52b79dc8fbbd962683bc36',1,'QMSTruckingRouteSearchOption::get_speed']]],
  ['get_5fsubpois_7',['get_subpois',['../interface_q_m_s_poi_search_option.html#a49aa0b5afabb3efaaf19b2f33bd57377',1,'QMSPoiSearchOption::get_subpois'],['../interface_q_m_s_suggestion_search_option.html#a022d4bcdb432eb7cb0d77b1c7b65247e',1,'QMSSuggestionSearchOption::get_subpois']]],
  ['getaggregationunit_3a_8',['getAggregationUnit:',['../interface_q_vector_heat_overlay.html#a33a877a440d54becf8c6fab383a4ea44',1,'QVectorHeatOverlay']]],
  ['getcoordinates_3arange_3a_9',['getCoordinates:range:',['../interface_q_multi_point.html#af8f0b03a6d552ae44db866eaae969168',1,'QMultiPoint']]],
  ['getdebugerror_10',['getDebugError',['../category_q_map_view_07_debug_08.html#a21e9040c774ea10c030031bb6015ff61',1,'QMapView(Debug)::getDebugError()'],['../interface_q_map_view.html#a21e9040c774ea10c030031bb6015ff61',1,'QMapView::getDebugError()']]],
  ['getmapcacheclearsizelimitbytype_3a_11',['getMapCacheClearSizeLimitByType:',['../interface_q_map_services.html#a8521b7c5a1d3df1f27843e0872fdf4f8',1,'QMapServices']]],
  ['getoff_12',['getoff',['../interface_q_m_s_busing_route_transit_line.html#a421dcc84e6dcff45c9c0a0cc545638cd',1,'QMSBusingRouteTransitLine']]],
  ['geton_13',['geton',['../interface_q_m_s_busing_route_transit_line.html#afdc5009514ab429d0497fbd883c16a1b',1,'QMSBusingRouteTransitLine']]],
  ['gettype_14',['getType',['../interface_q_g_l_overlay.html#add45689595ca4e2b671693f65add4714',1,'QGLOverlay']]],
  ['gloverlay_3adidtap_3a_15',['glOverlay:didTap:',['../protocol_q_g_l_overlay_delegate-p.html#a35159914885fc55184a7b1f627402581',1,'QGLOverlayDelegate-p']]],
  ['gloverlay_3aloadstatus_3awithprogress_3a_16',['glOverlay:loadStatus:withProgress:',['../protocol_q_g_l_overlay_delegate-p.html#a89d557a856b7540389060e25500ae741',1,'QGLOverlayDelegate-p']]],
  ['glpointratio_17',['glPointRatio',['../interface_q_g_l_overlay.html#a3bfc3b02b8cb1671efe1a2f9a67febe5',1,'QGLOverlay::glPointRatio()'],['../interface_q_map_view.html#a1153b3001c1bf2d26ae1a7cc6deac724',1,'QMapView::glPointRatio()']]],
  ['glprojectionmatrix_18',['glProjectionMatrix',['../interface_q_g_l_overlay.html#a112a5d88c014a912afa040891a8b855f',1,'QGLOverlay::glProjectionMatrix()'],['../interface_q_map_view.html#a10f669fc7d40926b07dbf0c7094c4dc3',1,'QMapView::glProjectionMatrix()']]],
  ['glvertexforcoordinate_3a_19',['glVertexForCoordinate:',['../interface_q_g_l_overlay.html#aad3349a4257ddbb13ddbae55e63ccaa6',1,'QGLOverlay::glVertexForCoordinate:()'],['../interface_q_map_view.html#afc8017803591b5e9f311991c82c80452',1,'QMapView::glVertexForCoordinate:()']]],
  ['glviewmatrix_20',['glViewMatrix',['../interface_q_g_l_overlay.html#a9c3ba591a9b63f3d02d762e1c1d1aafd',1,'QGLOverlay::glViewMatrix()'],['../interface_q_map_view.html#ae53128be3cb0722e367cd10cad4eac3b',1,'QMapView::glViewMatrix()']]],
  ['goods_5ftype_21',['goods_type',['../interface_q_m_s_truck_distance_matrix_search_option.html#a8b1570b3928ec37c647ce84f61ac84f2',1,'QMSTruckDistanceMatrixSearchOption::goods_type'],['../interface_q_m_s_trucking_route_search_option.html#ab7e949c3b8f1b9c487b48e101491b0af',1,'QMSTruckingRouteSearchOption::goods_type']]],
  ['gradient_22',['gradient',['../interface_q_heat_overlay.html#a0f6e888b1b6661f201a8f2522601f9c8',1,'QHeatOverlay::gradient'],['../interface_q_heat_tile_overlay.html#a100bde6f740ac39c4f726d73527000d8',1,'QHeatTileOverlay::gradient'],['../interface_q_masking_layer.html#a913bd5b434bac88e60e27baa2a0b0a3c',1,'QMaskingLayer::gradient']]],
  ['gravityline_23',['gravityLine',['../interface_q_user_location_presentation.html#ab85b87e9bbcdc13d6e88a84e18245882',1,'QUserLocationPresentation']]],
  ['groundoverlaywithbounds_3aicon_3a_24',['groundOverlayWithBounds:icon:',['../interface_q_ground_overlay.html#aa96e4b1bc372286ba4084eec5e584277',1,'QGroundOverlay']]],
  ['groundoverlaywithcoordinate_3azoomlevel_3aanchor_3aicon_3a_25',['groundOverlayWithCoordinate:zoomLevel:anchor:icon:',['../interface_q_ground_overlay.html#abc35c27890b4f108fa06e80a2c335b3b',1,'QGroundOverlay']]],
  ['gsversion_26',['GSVersion',['../interface_q_map_services.html#a08a58ead347c42749663728d06737637',1,'QMapServices']]],
  ['guid_27',['guid',['../interface_q_indoor_building.html#a81c1f56da5b767ab06d6f8ef6b2f7e24',1,'QIndoorBuilding']]]
];
